<?php
/*
Plugin Name: Videoframes
Plugin URI: http://videoframes1.ru
Description: Настройте внешний вид встраиваемых Вами видео с YouTube, добавьте роскошные iPod, iPad или другие типы современных стилей оформления.
Version: 1.0.0
Author: Александр Иванчин
Author URI: http://aleksandrivanchin.com
*/

 // exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

/**
 * Videoframes class.
 *
 * @class Videoframes
 * @version	2.0.0
 */
class Videoframes {
	
	private static $_instance;
	public $skins = array();
	public $defaults = array(
		'src'				=> 'https://www.youtube.com/watch?v=vmDzlkSP5ng',
		'skin'				=> 10,
		'autoplay'			=> true,
		'controls'			=> true,
		'loop'				=> false,
		'rel'				=> false,
		'headline_text'		=> '',
		'headline_color'	=> '#000000',
		'headline_size'		=> '22',
		'version'		=> '1.0.0'
	);
	
	private function __clone() {}
	private function __wakeup() {}
	
	/**
	 * WP Tube Video instance.
	 */
	public static function instance() {
		if ( self::$_instance === null ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * WP Tube Video constructor.
	 */
	public function __construct() {
		register_activation_hook( __FILE__, array( &$this, 'activation' ) );
		register_deactivation_hook( __FILE__, array( &$this, 'deactivation' ) );
		
		// actions
		add_action( 'init', array( &$this, 'register_shortcode' ) );
		add_action( 'admin_head', array( &$this, 'button_init' ) );
		add_action( 'plugins_loaded', array( &$this, 'load_textdomain' ) );
		add_action( 'plugins_loaded', array( &$this, 'load_defaults' ) );
		add_action( 'admin_print_scripts', array( &$this, 'admin_print_scripts' ) );
	}
	
	/**
	 * Plugin activation function.
	 */
	public function activation() {
		add_option( 'videoframes_version', $this->defaults['version'], '', 'no' );
	}
	
	/**
	 * Plugin deactivation function.
	 */
	public function deactivation() {
		delete_option( 'videoframes_version' );
	}
	
	/**
	 * Register shortcode.
	 */
	public function register_shortcode() {
		add_shortcode( 'videoframes', array( &$this, 'add_shortcode' ) );
		// backward compatibility
		add_shortcode( 'awsmvid', array( &$this, 'add_shortcode_old' ) );
	}
	
	/**
	 * Load text domain.
	 */
	public function load_textdomain() {
		load_plugin_textdomain( 'videoframes', false, plugin_dir_path( __FILE__ ) . 'languages/' );
	}
	
	/**
	 * Load defaults.
	 */
	public function load_defaults() {
		$this->skins = array(
			'1'	 => __( 'iPad 2 (black)', 'videoframes' ),
			'2'	 => __( 'iPad 2 (white)', 'videoframes' ),
			'18' => __( 'iPhone 4 (black)', 'videoframes' ),
			'5'	 => __( 'iPhone 5 (black)', 'videoframes' ),
			'6'	 => __( 'iPhone 5 (white)', 'videoframes' ),
			'7'	 => __( 'Macbook Air', 'videoframes' ),
			'8'	 => __( 'Macbook Pro', 'videoframes' ),
			'9'	 => __( 'iMac', 'videoframes' ),
			'10' => __( 'GalaxyS5 (black)', 'videoframes' ),
			'11' => __( 'GalaxyS5 (white)', 'videoframes' ),
			'12' => __( 'Nexus 4', 'videoframes' ),
			'13' => __( 'HD LCD TV', 'videoframes' ),
			'14' => __( 'Monolith TV', 'videoframes' ),
			'16' => __( 'PC Monitor', 'videoframes' ),
			'17' => __( 'Shadow', 'videoframes' ),
			'20' => __( 'Hand 1', 'videoframes' ),
			'21' => __( 'Hand 2', 'videoframes' ),
			'22' => __( 'Hand 3', 'videoframes' ),
			'23' => __( 'iPad Screen', 'videoframes' ),
			'24' => __( 'iPhone 6', 'videoframes' ),
			'25' => __( 'Filmstrip 1', 'videoframes' ),
			'26' => __( 'Filmstrip 2', 'videoframes' ),
			'27' => __( 'Samsung Galaxy S6', 'videoframes' ),
			'28' => __( 'Hand 1 Black Tablet', 'videoframes' ),
			'29' => __( 'Hand 2 Black Tablet', 'videoframes' ),
			'30' => __( 'Hand 3 Black Tablet', 'videoframes' ),
			'31' => __( 'Hand 4', 'videoframes' ),
			'32' => __( 'Hand 4 Black Tablet', 'videoframes' ),
			'33' => __( 'Samsung Galaxy S6 Curved Edge', 'videoframes' ),
			'34' => __( 'Grunge 1', 'videoframes' ),
			'35' => __( 'Grunge 2', 'videoframes' ),
			'36' => __( 'Grunge 3', 'videoframes' ),
			'37' => __( 'Grunge 4', 'videoframes' ),
			'38' => __( 'Grunge 5', 'videoframes' ),
			'40' => __( 'Classic Frame 1', 'videoframes' ),
			'41' => __( 'Classic Frame 2', 'videoframes' ),
			'42' => __( 'Classic Frame 3', 'videoframes' ),
			'43' => __( 'Creative Frame 1', 'videoframes' ),
			'44' => __( 'Creative Frame 2', 'videoframes' ),
			'45' => __( 'Creative Frame 3', 'videoframes' ),
			'46' => __( 'Creative Frame 4', 'videoframes' ),
			'47' => __( 'Creative Frame 5', 'videoframes' ),
			'48' => __( 'Ornamental Frame 1', 'videoframes' ),
			'49' => __( 'Ornamental Frame 2', 'videoframes' ),
			'50' => __( 'Ornamental Frame 3', 'videoframes' ),
		);
	}
	
	/**
	 * Print admin scripts, generate poopup spinner.
	 */
	public function admin_print_scripts() {
		global $typenow;
		
		if ( ! current_user_can( 'edit_posts' ) && ! current_user_can( 'edit_pages' ) ) {
			return;
		}
		
		// verify post type
		if( ! in_array( $typenow, array( 'post', 'page' ) ) ) {
			return;
		}
		?>
		<style>
			#videoframes-insert-dialog-body {
				background-image: url(<?php echo admin_url() . 'images/spinner.gif'; ?>);
				background-position: center center;
				background-repeat: no-repeat;
				-webkit-background-size: 20px 20px;
				background-size: 20px 20px;
			}
		</style>
		<?php
	}

	/**
	 * Admin init.
	 */
	public function button_init() {
		global $typenow;
		
		if ( ! current_user_can( 'edit_posts' ) && ! current_user_can( 'edit_pages' ) ) {
			return;
		}
		
		// verify post type
		if( ! in_array( $typenow, array( 'post', 'page' ) ) ) {
			return;
		}
		
		// check if WYSIWYG is enabled
		if ( get_user_option( 'rich_editing' ) == 'true' ) {
			add_filter( 'mce_buttons', array( &$this, 'filter_mce_button' ) );
			add_filter( 'mce_external_plugins', array( &$this, 'filter_mce_plugin' ) );
			// add_filter( 'mce_external_languages', array( &$this, 'filter_mce_lang') );
		}
	}
	
	/**
	 * Add tinymce toolbar button.
	 * 
	 * @param	array	$buttons
	 * @return	array
	 */
	public function filter_mce_button( $buttons ) {
		array_push( $buttons, 'videoframes' );
		return $buttons;
	}
	
	/**
	 * Handle tinymce button.
	 * 
	 * @param	array	$plugins
	 * @return	array
	 */
	public function filter_mce_plugin( $plugins ) {
		$plugins['videoframes'] = plugins_url( 'tinymce-plugin.js', __FILE__ );
		return $plugins;
	}
	
	/**
	 * Handle button languages.
	 * 
	 * @param	array	$locales
	 * @return	array
	 */
	public function filter_mce_lang( $locales ) {
		$locales['videoframes'] = plugin_dir_path( __FILE__ ) . 'includes/tinymce-lang.php';
		return $locales;
	}
	
	/**
	 * Register shortcode.
	 * 
	 * @param	array	$atts
	 * @param	mixed	$content
	 * @return	array
	 */
	public function add_shortcode( $atts, $content = null ) {

		wp_register_style( 'videoframes_style', plugins_url( 'css/style.css', __FILE__ ) );
		wp_enqueue_style( 'videoframes_style');
		
		$atts = shortcode_atts( array(
			'src'				=> $this->defaults['src'],
			'skin'				=> $this->defaults['skin'],
			'autoplay'			=> $this->defaults['autoplay'],
			'controls'			=> $this->defaults['controls'],
			'loop'				=> $this->defaults['loop'],
			'headline_text'		=> '',
			'headline_color'	=> '',
			'headline_size'		=> '',
			'rel'				=> $this->defaults['rel'],
		), $atts, 'videoframes' );
		
		$atts['src']			= esc_url( $atts['src'] );
		$atts['skin']			= absint( $atts['skin'] );
		$atts['autoplay']		= absint( (bool) $atts['autoplay'] );
		$atts['controls']		= absint( (bool) $atts['controls'] );
		$atts['loop']			= absint( (bool) $atts['loop'] );
		$atts['headline_text']	= trim( esc_html( $atts['headline_text'] ) );
		$atts['headline_color']	= esc_html( $atts['headline_color'] );
		$atts['headline_size']	= absint( $atts['headline_size'] );
		$atts['rel']			= absint( (bool) $atts['rel'] );
		
		extract( $atts );
		
		// get youtube video id
		$youtube_pattern = '~(?:http|https|)(?::\/\/|)(?:www.|)(?:youtu\.be\/|youtube\.com(?:\/embed\/|\/v\/|\/watch\?v=|\/ytscreeningroom\?v=|\/feeds\/api\/videos\/|\/user\S*[^\w\-\s]|\S*[^\w\-\s]))([\w\-]{11})[a-z0-9;:@#?&%=+\/\$_.-]*~i';
		
		$youtube_id = preg_match( $youtube_pattern, $src ) != 0 ? preg_replace( $youtube_pattern, '$1', $src ) : false;
		
		// get vimeo video id
		if ( ! $youtube_id ) {
			$vimeo_pattern = '/(?:http|https|)(?::\/\/|)(?:www.|)(?:vimeo\.com\/)([0-9]*(?:.+))/i';
			
			$vimeo_id = preg_match( $vimeo_pattern, $src ) ? preg_replace( $vimeo_pattern, '$1', $src ) : false;
		}
		
		// get extra styles
		$style = '';
		
		if ( $headline_color ) {
			$style .= ' color: ' . $headline_color . ';';
		}
		
		if ( $headline_size ) {
			$style .= ' font-size: ' . $headline_size . 'px;';
		}
		
		if ( $youtube_id ) {
			// youtube iframe
			$iframe = '<div class="videoframes videoframes-skin-' . $skin . '">';
			if ( $headline_text != '' ) {
				$iframe .= '<div class="videoframes-headline" style="' . $style . '">' . $headline_text . '</br><span class="videoframes-headline-arrow"></span></div>';
			}
			$iframe .= '<div class="videoframes-container"><iframe src="' . esc_url_raw( 'https://www.youtube.com/embed/' . $youtube_id . '?showinfo=0&modestbranding=1&controls=' . $controls . '&autoplay=' . $autoplay . '&loop=' . $loop . '&rel=' . $rel ) . '" frameborder="0" allowfullscreen></iframe></div></div>';
		} elseif ( $vimeo_id ) {
			// vimeo iframe
			$iframe = '<div class="videoframes videoframes-skin-' . $skin . '">';
			if ( ! $headline_text ) {
				$iframe .= '<div class="videoframes-headline" style="' . $style . '">' . $headline_text . '</br><span class="videoframes-headline-arrow"></span></div>';
			}
			$iframe .= '<div class="videoframes-container"><iframe src="https://player.vimeo.com/video/' . $vimeo_id . '?autoplay=' . $autoplay . '&loop=' . $loop . '&byline=0&badge=0" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe></div></div>';
		} else {
			$iframe = '';
		}

		return $iframe;

	}
	
	/**
	 * Register awsmvid shortcode for backward compatibility.
	 * 
	 * @param	array	$atts
	 * @param	mixed	$content
	 * @return	array
	 */
	public function add_shortcode_old( $atts, $content = null ) {

		wp_register_style( 'videoframes_style', plugins_url( 'css/style.css', __FILE__ ) );
		wp_enqueue_style( 'videoframes_style');
		
		$atts = shortcode_atts( array(
			'src'			=> $this->defaults['src'],
			'skins'			=> $this->defaults['skin'],
			'play'			=> $this->defaults['autoplay'],
			'hide'			=> $this->defaults['controls']
		), $atts, 'awsmvid' );
		
		$atts['src']		= esc_url( $atts['src'] );
		$atts['skins']		= absint( $atts['skins'] );
		$atts['play']		= absint( (bool) $atts['play'] );
		$atts['hide']		= absint( ! (bool) $atts['hide'] );
		
		extract( $atts );
		
		$youtube_id = $content;
		
		$iframe = '<div class="videoframes-container videoframes-skin-' . $skins . '"><iframe src="' . esc_url_raw( 'https://www.youtube.com/embed/' . $youtube_id . '?showinfo=0&controls=' . $hide . '&autoplay=' . $play ) . '" frameborder="0" allowfullscreen></iframe></div>';

		return $iframe;

	}
	
}

/**
 * Initialise Videoframes.
 */
function Videoframes() {
	static $instance;

	// first call to instance() initializes the plugin
	if ( $instance === null || ! ( $instance instanceof Videoframes ) ) {
		$instance = Videoframes::instance();
	}

	return $instance;
}

$videoframes = Videoframes();
?>